@@ -2,7 +2,8 @@
 #' removes unwanted sides from the images.)
 #'@description Esta funcao permite cortar a imagem (This function allows you to
 #'  crop the image).
-#'@usage crop_image(im,w=NULL,h=NULL,segmentation=NULL,plot=TRUE,verbose=FALSE)
+#'@usage crop_image(im,w=NULL,h=NULL,segmentation=NULL,plot=TRUE,
+#'    extent=NULL,verbose=FALSE)
 #'@param im Este objeto deve conter uma imagem no formato do EBImage (This
 #'  object must contain an image in EBImage format).
 #'@param w Deve ser um vetor contendo os numeros das colunas que permanecerao na
@@ -16,6 +17,10 @@
 #'@param plot Indica se sera apresentada (TRUE) ou nao (FALSE) (default) a
 #'  imagem segmentada (Indicates whether the segmented image will be
 #'  displayed (TRUE) or not (FALSE) (default)).
+#'@param extent Caso a imagem seja do tipo TIF este objeto devera ter um vetor com quatro valores
+#' de coordenadas que delimitam a area a ser cortada. Neste caso o argumento raster deve ser TRUE
+#'(If the image is of type TIF, this object must have a vector with four coordinate values that
+#' delimit the area to be cut. In this case the raster argument must be TRUE).
 #'@param verbose Indica se sera apresentada (TRUE) ou nao (FALSE) (default) os
 #'pontos de corte (Indicates whether the segmented image will be
 #'  displayed (TRUE) or not (FALSE) (default) the points crop).
@@ -35,23 +40,37 @@
 #'#Carregar imagem de exemplo
 #'im=read_image(example_image(2),plot=TRUE)
 #'
-#'
 #'##Cortar Imagem
-#'
 #'im3=crop_image(im,w =286:421,h=242:332,plot = TRUE)
 #'
+#' #Exemplo utilizando mascara
+#' imb=read_image(example_image(2),plot=TRUE)
+#' m=gray_scale(imb,"g/rgb",plot=TRUE)
+#' mask=segmentation(m,threshold="otsu",plot=TRUE)
+#' imc=crop_image(imb,segmentation=mask,plot=TRUE)
+#'
 #'# intefacie grafica
 #'\dontrun{
+#'im=read_image(example_image(2),plot=TRUE)
 #'im2=crop_image(im)
 #'}
+#'
 
 #'
 
 
 
 
-crop_image=function(im,w=NULL,h=NULL,segmentation=NULL,plot=TRUE,verbose=FALSE){
-n=1
+crop_image=function(im,w=NULL,h=NULL,segmentation=NULL,plot=TRUE,extent=NULL,verbose=FALSE){
+  classe=class(im)
+  raster=FALSE
+  if(length(classe)>1) classe=classe[1]
+
+  if((classe=="RasterStack")|(classe=="RasterBrick")){ raster=TRUE
+ }
+
+  if(raster==FALSE){
+  n=1
   nr=dim(im)[1]
   nc=dim(im)[2]
   l=length(dim(im))
@@ -129,6 +148,15 @@ if(!is.null(segmentation)){
 }
 
 
+  if(raster==TRUE){
+    imb=raster::crop(im,raster::extent(extent))
+   # imb=raster:stack(im)
+   if(plot==TRUE){plot_image(imb)}
+    return(imb)
+
+  }
+}
+
 
 
 
