@@ -60,6 +60,9 @@
 #'#Mostrando ambas as imagens simultaneamente.
 #'im4=join_image(im3,imb)
 #'}
+#'
+#'
+
 #' @export
 #' @exportS3Method print edit_image
 
@@ -70,8 +73,9 @@ edit_image=function(im,brightness=0,contrast=1,gamma =1,plot=T){
     im@.Data=im@.Data+brightness
     im@.Data=im@.Data*contrast
     im@.Data=im@.Data^gamma
-
-    im=EBImage::normalize(im,ft=c(0,1))
+    im@.Data[im@.Data>1]=1
+    im@.Data[im@.Data<0]=0
+    #im=EBImage::normalize(im,ft=c(0,1))
     if(plot==T){plot_image(im)}
   }
 
@@ -79,8 +83,9 @@ edit_image=function(im,brightness=0,contrast=1,gamma =1,plot=T){
     im=im+brightness
     im=im*contrast
     im=im^gamma
-
-    im=EBImage::normalize(im,ft=c(0,1))
+im[im>1]=1
+im[im<0]=0
+   # im=EBImage::normalize(im,ft=c(0,1))
     if(plot==T){plot_image( EBImage::as.Image(im))}
   }
 
