@@ -4,7 +4,7 @@
 #' @description Esta funcao permite criar mascara sobre os pixels
 #'   correspondentes ao background ou foreground
 #' @usage mask_pixels(im,TargetPixels,TargetPixels2=NULL,col.TargetPixels="rand",
-#' Contour=FALSE,plot=FALSE)
+#' Contour=FALSE, r = 1, g = 2, b = 3, norma = 1,plot=FALSE)
 
 #' @param im    :Este objeto deve conter uma imagem no formato do EBImage.
 #' @param TargetPixels    : Este objeto deve ser  uma matriz
@@ -16,8 +16,12 @@
 #' @param col.TargetPixels : Se for a palavra "rand" serao valores escolhidos para cada matriz.
 #' Pode tambem ser um vetor contendo os nomes das cores. Neste caso, o tamanho de vetor deve ser igual
 #' ao numero de matrizes.
-#' @param Contour Valor logico. Se for FALSE (default) sera a parte de interesse sera preenchida.
+#' @param Contour : Valor logico. Se for FALSE (default) sera a parte de interesse sera preenchida.
 #' Se for TRUE a area de interesse sera contornada.
+#' @param r : Camada correspondente a banda de vermelho.
+#' @param g : Camada correspondente a banda de verde
+#' @param b = Camada correspondente a banda de azul
+#' @param norma = Valor a ser dividido em cada pixel para se ter valor entre 0 e 1.
 #' @param plot    :Indica se sera apresentada (TRUE) ou nao (FALSE) (default) a
 #'   imagem segmentada.
 
@@ -83,15 +87,31 @@
 #' @export
 #' @exportS3Method print mask_pixels
 
-mask_pixels=function(im,TargetPixels,TargetPixels2=NULL,col.TargetPixels="rand",Contour=FALSE,plot=FALSE){
+mask_pixels=function(im,TargetPixels,TargetPixels2=NULL,
+                     col.TargetPixels="rand",Contour=FALSE,
+                     r=1,g=2,b=3,norma=1,plot=FALSE){
  # TargetPixels==1
 
+  classe=class(im)
+  raster=FALSE
+  if(length(classe)>1) classe=classe[1]
+
+  if((classe=="RasterStack")|(classe=="RasterBrick")|(classe=="RasterLayer")){ raster=TRUE
+
+  }
+
+
+  color=col.TargetPixels
+
+  if(raster==FALSE){
+
   if(!is.list(TargetPixels)){TargetPixels=list(TargetPixels)}
   if(!is.list(TargetPixels2)){TargetPixels2=list(TargetPixels2)}
 
-  TargetPixels=c(TargetPixels,TargetPixels2)
+  if(!is.null(TargetPixels2[[1]])) TargetPixels=c(TargetPixels,TargetPixels2)
 n=length(TargetPixels)
 
+rr=gg=bb=NULL
   if(col.TargetPixels[1]=="rand"){
     rr=runif(n,0,1)
     gg=runif(n,0,1)
@@ -110,15 +130,14 @@ n=length(TargetPixels)
 
 
   a=0
-
   for( i in 1:n) {
     if(!is.null(TargetPixels[[i]][[1]])){
     a=a+1
     if(col.TargetPixels[1]!="rand"){
         cc=c(grDevices::col2rgb(col.TargetPixels[a])/255)
-        rr=cc[1]
-        gg=cc[2]
-        bb=cc[3]
+        rr=c(rr,cc[1])
+        gg=c(gg,cc[2])
+        bb=c(bb,cc[3])
 
       }
 
@@ -126,12 +145,12 @@ n=length(TargetPixels)
   r=im@.Data[,,1]
   g=im@.Data[,,2]
   b=im@.Data[,,3]
-ID=EBImage::as.Image(TargetPixels[[i]])
-  ID=ID@.Data==1
+ID=EBImage::as.Image(TargetPixels[[a]])
+  ID=ID@.Data==TRUE
   if(isTRUE(Contour)){ID=contour_image(ID==1,plot=F)==1}
-  r[ID]=rr
-  g[ID]=gg
-  b[ID]=bb
+  r[ID]=rr[a]
+  g[ID]=gg[a]
+  b[ID]=bb[a]
 
   im@.Data[,,1]=r
   im@.Data[,,2]=g
@@ -139,7 +158,50 @@ ID=EBImage::as.Image(TargetPixels[[i]])
 
   }
   }
+
+
+
 if(plot==T){plot_image(im)}
+  }
+
+
+######################
+  ################
+  ###############
+  #
+
+  if(raster==TRUE){
+    if(!is.list(TargetPixels)){TargetPixels=list(TargetPixels)}
+    if(!is.list(TargetPixels2)){TargetPixels2=list(TargetPixels2)}
+    if(!is.null(TargetPixels2[[1]])){
+    TargetPixels=c(TargetPixels,TargetPixels2)}
+    n=length(TargetPixels)
+
+    if(col.TargetPixels[1]=="rand"){
+      rr=runif(n,0,1)
+      gg=runif(n,0,1)
+      bb=runif(n,0,1)
+      color=rgb(rr,gg,bb)
+    }
+
+
+
+    a=0
+
+    raster::plotRGB(im,r=r,g=g,b=b,axes=FALSE,stretch="lin")
+    for( i in 1:n) {
+      TP=TargetPixels[[i]]
+      raster::plot(TP,col=color[i],add=TRUE,legend=FALSE)
+
+      }
+  }
+
+
+
+
+
+
+
   return(im)
 }
 
